from .client import HidalgoGacetaClient
from .models import HidalgoGaceta, HidalgoDocumento, HidalgoGacetaDetalle

__all__ = ["HidalgoGacetaClient", "HidalgoGaceta",
           "HidalgoDocumento", "HidalgoGacetaDetalle"]
