from .client import AguascalientesClient, TIPOS_PROMOCION, LEGISLATURAS
from .models import AgsPromocion, AgsComision

__all__ = [
    "AguascalientesClient",
    "AgsPromocion",
    "AgsComision",
    "TIPOS_PROMOCION",
    "LEGISLATURAS",
]
